## $Id: applicant.py 10814 2013-11-29 10:06:18Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from waeup.kofa.applicants.applicant import ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from waeup.kofa.applicants.applicant import Applicant
from kofacustom.ekodisco.applicants.interfaces import(
    ICustomApplicant, ICustomApplicantEdit)

class CustomApplicant(Applicant):

    grok.implements(ICustomApplicant, ICustomApplicantEdit)
    grok.provides(ICustomApplicant)

    create_names = [
        'firstname', 'middlename', 'lastname',
        'date_of_birth',
        'email', 'phone', 'perm_address'
        ]

    def _setStudyCourseAttributes(self, studycourse):
        #studycourse.entry_mode = self.course_admitted.study_mode
        #studycourse.current_level = self.course_admitted.start_level
        studycourse.service_address = self.service_address
        studycourse.certificate = self.course_admitted
        studycourse.entry_session = self.__parent__.year
        studycourse.current_session = self.__parent__.year
        return

# Set all attributes of CustomApplicant required in ICustomApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
CustomApplicant = attrs_to_fields(CustomApplicant)

class CustomApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return CustomApplicant()

    def getInterfaces(self):
        return implementedBy(CustomApplicant)
